import MockAdapter from 'axios-mock-adapter';

import TelegramClient from '../TelegramClient';

const ACCESS_TOKEN = '123456:ABC-DEF1234ghIkl-zyx57W2v1u123ew11';

const createMock = () => {
  const client = new TelegramClient(ACCESS_TOKEN);
  const mock = new MockAdapter(client.axios);
  return { client, mock };
};

describe('game api', () => {
  describe('sendGame', () => {
    it('should send a game', async () => {
      const { client, mock } = createMock();
      const result = {
        message_id: 66,
        from: {
          id: 313534466,
          first_name: 'first',
          username: 'a_bot',
        },
        chat: {
          id: 427770117,
          first_name: 'first',
          last_name: 'last',
          type: 'private',
        },
        date: 1499402829,
        game: {
          title: 'Mario Bros.',
          description: 'Mario Bros. is fun!',
          photo: [
            {
              file_id:
                'AgADBAADGTo4Gz8cZAeR-ouu4XBx78EeqRkABHahi76pN-aO0UoDA050',
              file_size: 14650,
              width: 160,
              height: 160,
            },
            {
              file_id:
                'AgADBAADGTo4Gz8cZAeR-ouu4XBx78EeqRkABKCfooqTgFUX0EoD5B1C',
              file_size: 39019,
              width: 320,
              height: 320,
            },
            {
              file_id:
                'AgADBAADGTo4Gz8cZAeR-ouu4XBx78EeqRkABPL_pC9K3UpI0koD1B1C',
              file_size: 132470,
              width: 640,
              height: 640,
            },
          ],
        },
      };
      const reply = {
        ok: true,
        result,
      };

      mock
        .onPost('/sendGame', {
          chat_id: 427770117,
          game_short_name: 'Mario Bros.',
          disable_notification: true,
        })
        .reply(200, reply);

      const res = await client.sendGame(427770117, 'Mario Bros.', {
        disable_notification: true,
      });

      expect(res).toEqual(result);
    });
  });

  describe('setGameScore', () => {
    it('should set the score of the specified user in a game', async () => {
      const { client, mock } = createMock();
      const result = {
        message_id: 66,
        from: {
          id: 313534466,
          first_name: 'first',
          username: 'a_bot',
        },
        chat: {
          id: 427770117,
          first_name: 'first',
          last_name: 'last',
          type: 'private',
        },
        date: 1499402829,
        game: {
          title: 'Mario Bros.',
          description: 'Mario Bros. is fun!',
          photo: [
            {
              file_id:
                'AgADBAADGTo4Gz8cZAeR-ouu4XBx78EeqRkABHahi76pN-aO0UoDA050',
              file_size: 14650,
              width: 160,
              height: 160,
            },
            {
              file_id:
                'AgADBAADGTo4Gz8cZAeR-ouu4XBx78EeqRkABKCfooqTgFUX0EoD5B1C',
              file_size: 39019,
              width: 320,
              height: 320,
            },
            {
              file_id:
                'AgADBAADGTo4Gz8cZAeR-ouu4XBx78EeqRkABPL_pC9K3UpI0koD1B1C',
              file_size: 132470,
              width: 640,
              height: 640,
            },
          ],
          text: 'User 427770117 score is 999.',
        },
      };
      const reply = {
        ok: true,
        result,
      };

      mock
        .onPost('/setGameScore', { user_id: 427770117, score: 999 })
        .reply(200, reply);

      const res = await client.setGameScore(427770117, 999);

      expect(res).toEqual(result);
    });
  });

  describe('getGameHighScores', () => {
    it('should get data for high score tables', async () => {
      const { client, mock } = createMock();
      const result = [
        {
          position: 1,
          user: {
            id: 427770117,
            is_bot: false,
            first_name: 'first',
          },
          score: 999,
        },
      ];
      const reply = {
        ok: true,
        result,
      };

      mock
        .onPost('/getGameHighScores', { user_id: 427770117 })
        .reply(200, reply);

      const res = await client.getGameHighScores(427770117);

      expect(res).toEqual(result);
    });
  });
});
